@@ -1,7 +1,7 @@
 package Perinci::Examples::Completion;
 
-our $DATE = '2019-06-29'; # DATE
-our $VERSION = '0.814'; # VERSION
+our $DATE = '2019-07-06'; # DATE
+our $VERSION = '0.815'; # VERSION
 
 use 5.010;
 use strict;
@@ -71,6 +71,39 @@ sub fruits {
     [200, "OK", {@_}];
 }
 
+$SPEC{animal_choice} = {
+    v => 1.1,
+    summary => 'Specify an animal (optional), some examples given in schema (for completion)',
+    args => {
+        animal => {
+            schema => ['str*', {
+                'x.examples' => [
+                    'dog',
+                    'bird',
+                    'elephant',
+                ],
+                'x.examples.summaries' => [
+                    'You cannot teach this animal new tricks when it is old',
+                    'Two of this can be killed with one stone',
+                    'It never forgets',
+                ],
+            }],
+            pos => 0,
+        },
+    },
+    description => <<'_',
+
+Demonstrates `x.examples` and `x.examples.summaries` Sah schema attributes.
+Unlike the `in` clause, the value of an argument is not restricted to only
+values specified in the `x.examples`. `x.examples` serves to give examples of
+valid values, hint for completion, etc.
+
+_
+};
+sub animal_choice {
+    [200, "OK", {@_}];
+}
+
 1;
 # ABSTRACT: More completion examples
 
@@ -86,13 +119,49 @@ Perinci::Examples::Completion - More completion examples
 
 =head1 VERSION
 
-This document describes version 0.814 of Perinci::Examples::Completion (from Perl distribution Perinci-Examples), released on 2019-06-29.
+This document describes version 0.815 of Perinci::Examples::Completion (from Perl distribution Perinci-Examples), released on 2019-07-06.
 
 =for Pod::Coverage .*
 
 =head1 FUNCTIONS
 
 
+=head2 animal_choice
+
+Usage:
+
+ animal_choice(%args) -> [status, msg, payload, meta]
+
+Specify an animal (optional), some examples given in schema (for completion).
+
+Demonstrates C<x.examples> and C<x.examples.summaries> Sah schema attributes.
+Unlike the C<in> clause, the value of an argument is not restricted to only
+values specified in the C<x.examples>. C<x.examples> serves to give examples of
+valid values, hint for completion, etc.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<animal> => I<str>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
 =head2 fruits
 
 Usage:
